@@ -1,6 +1,6 @@
 use rowan::TextRange;
 use squawk_syntax::{
-    ast::{self, AstNode, HasModuleItem},
+    ast::{self, AstNode},
     Parse, SourceFile,
 };
 
@@ -8,8 +8,8 @@ use crate::{Linter, Rule, Violation};
 
 pub(crate) fn ban_create_domain_with_constraint(ctx: &mut Linter, parse: &Parse<SourceFile>) {
     let file = parse.tree();
-    for item in file.items() {
-        if let ast::Item::CreateDomain(domain) = item {
+    for stmt in file.stmts() {
+        if let ast::Stmt::CreateDomain(domain) = stmt {
             let range =
                 domain
                     .constraints()
