@@ -1,7 +1,7 @@
 use std::collections::HashSet;
 
 use squawk_syntax::{
-    ast::{self, AstNode, HasArgList},
+    ast::{self, AstNode},
     Parse, SourceFile,
 };
 
