@@ -49,19 +49,15 @@ use event::Event;
 use grammar::OPERATOR_FIRST;
 use std::cell::Cell;
 use token_set::TokenSet;
+mod event;
+mod generated;
 mod grammar;
-mod token_set;
-
+mod input;
 mod lexed_str;
+mod output;
 mod shortcuts;
 mod syntax_kind;
-
-mod event;
-mod input;
-mod output;
-
-#[cfg(test)]
-mod test;
+mod token_set;
 
 pub use crate::{
     lexed_str::LexedStr,
@@ -213,8 +209,8 @@ impl<'t> Parser<'t> {
             return false;
         }
         let n_raw_tokens = match kind {
-            SyntaxKind::COLON2
-            | SyntaxKind::COLONEQ
+            SyntaxKind::COLON_COLON
+            | SyntaxKind::COLON_EQ
             | SyntaxKind::NEQ
             | SyntaxKind::NEQB
             | SyntaxKind::LTEQ
@@ -511,14 +507,14 @@ impl<'t> Parser<'t> {
                 TrivaBetween::NotAllowed,
             ),
             // :=
-            SyntaxKind::COLONEQ => self.at_composite2(
+            SyntaxKind::COLON_EQ => self.at_composite2(
                 n,
                 SyntaxKind::COLON,
                 SyntaxKind::EQ,
                 TrivaBetween::NotAllowed,
             ),
             // ::
-            SyntaxKind::COLON2 => self.at_composite2(
+            SyntaxKind::COLON_COLON => self.at_composite2(
                 n,
                 SyntaxKind::COLON,
                 SyntaxKind::COLON,
@@ -545,13 +541,6 @@ impl<'t> Parser<'t> {
                 SyntaxKind::NOT_KW,
                 TrivaBetween::Allowed,
             ),
-            // is null
-            SyntaxKind::IS_NULL => self.at_composite2(
-                n,
-                SyntaxKind::IS_KW,
-                SyntaxKind::NULL_KW,
-                TrivaBetween::Allowed,
-            ),
             // not like
             SyntaxKind::NOT_LIKE => self.at_composite2(
                 n,
